% Ejemplo de diseo de filtros analogicos con Matlab
%
% Encontrar las funciones de aproximacion de paso bajo de Butterworth,
% Chebyshev y eliptica para los requerimientos de un filtro:
% Amax=0.5dB, Amin=40dB, fp=1000Hz, fs=2000rad/seg
%
close all;
clear all;
s=tf('s');
Amax=0.5;
Amin=40;
Rs=Amin;
Rp=Amax;
Wp=2*pi*1000;
Ws=2*pi*2000;
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Obtenemos la funcion de aproximacion de Butterworth
[Nb, Wn] = BUTTORD(Wp, Ws, Rp, Rs, 's')
[NUM, DEN]=BUTTER (Nb,Wn,'s');
gbut=tf(NUM,DEN)
hbut=1/gbut;
% Comprobamos que se verifican las especificaciones
w=[Ws,Wp];
[mag]=bode(hbut,w);
magdB=20*log10(mag)
% Factorizamos la funcion de transferencia
[sosb,g]=tf2sos(NUM,DEN); % Ver en Workspace
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Obtenemos la funcion de aproximacion de Chebyshev
[Nc, Wnc] = CHEB1ORD(Wp, Ws, Rp, Rs, 's')
[NUM, DEN]=CHEBY1(Nc,Rp,Wnc,'s');
gcheb=tf(NUM,DEN)
hcheb=1/gcheb;
% Comprobamos que se verifican las especificaciones
[mag]=bode(hcheb,w);
magdB=20*log10(mag)
% Factorizamos la funcion de transferencia
[sosch,g]=tf2sos(NUM,DEN); % Ver en Workspace
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Obtenemos la funcion de aproximacion de Cauer
[Ne, Wne] = ELLIPORD(Wp, Ws, Rp, Rs, 's')
[NUM, DEN]=ELLIP(Ne,Rp,Rs,Wne,'s');
gcauer=tf(NUM,DEN)
hcauer=1/gcauer;
% Comprobamos que se verifican las especificaciones
[mag]=bode(hcauer,w);
magdB=20*log10(mag)
% Factorizamos la funcion de transferencia
[soscauer,g]=tf2sos(NUM,DEN); % Ver en Workspace
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dibujamos el diagrama de Bode de las tres funciones de perdidas obtenidas
bodemag(hbut,hcheb,hcauer);
title('');
legend(['Butterworth de orden ' num2str(Nb)], ...
    ['Chebyshev de orden ', num2str(Nc)],['Cauer de orden ', num2str(Ne)])